@@ -1,31 +1,29 @@
 #ifndef ECWIN7_H
 #define ECWIN7_H
 
-#include <QtGlobal>
 #include <QWidget>
+#include <QtGlobal>
 
-#include <QtWinExtras/QWinTaskbarButton>
-#include <QtWinExtras/QWinTaskbarProgress>
 #include <QtWinExtras/QWinJumpList>
 #include <QtWinExtras/QWinJumpListCategory>
+#include <QtWinExtras/QWinTaskbarButton>
+#include <QtWinExtras/QWinTaskbarProgress>
 
-class EcWin7
-{
-public:
-
+class EcWin7 {
+   public:
     // Initialization methods
     EcWin7();
-    void init(QWidget* wid);
-    void addRecentFile(const QString& filename);
+    void init(QWidget *wid);
+    void addRecentFile(const QString &filename);
 
     void setProgressValue(int value, int max);
 
-private:
+   private:
     void associateFileTypes(const QStringList &fileTypes);
 
-    QWinTaskbarButton* taskbarButton;
-    QWinTaskbarProgress* taskbarProgress;
-    QWinJumpList* jumplist;
+    QWinTaskbarButton *taskbarButton;
+    QWinTaskbarProgress *taskbarProgress;
+    QWinJumpList *jumplist;
 };
 
-#endif // ECWIN7_H
+#endif  // ECWIN7_H
