@@ -25,15 +25,22 @@
 #ifndef SAVINGPARAMETERSDIALOG_H
 #define SAVINGPARAMETERSDIALOG_H
 
-#include "ui_SavingParametersDialog.h"
+#include "TonemappingPanel/ui_SavingParametersDialog.h"
 
-class SavingParameters : public QDialog, private Ui::SavingParameters
-{
+namespace Ui {
+class SavingParameters;
+}
+
+class SavingParameters : public QDialog {
     Q_OBJECT
 
-public:
+   public:
     SavingParameters(QWidget *parent = 0);
-    QString getComment() { return comment->text(); }
+    ~SavingParameters();
+    QString getComment();
+
+   protected:
+    QScopedPointer<Ui::SavingParameters> m_Ui;
 };
 
 #endif
